==> eiffelstudio-18.01.10.1424.tar: F_code/C1/ew7.c <==
/*
 * Code for class EW_EWEASEL_OUTPUT_CONTROL
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew7.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_EWEASEL_OUTPUT_CONTROL}.make */
void F7_182 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("make", 6, Current, 0, 1, 185);
	RTGC;
	RTHOOK(1);
	tr1 = RTCCL(arg1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_EWEASEL_OUTPUT_CONTROL}.flush */
void F7_184 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("flush", 6, Current, 0, 0, 187);
	RTGC;
	RTHOOK(1);
	tr1 = RTOSCF(374,F25_374,(RTCV(RTOSCF(24,F1_24,(Current)))));
	F386_2494(RTCW(tr1));
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_EWEASEL_OUTPUT_CONTROL}.update */
void F7_185 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("update", 6, Current, 0, 0, 188);
	RTHOOK(1);
	F7_184(Current);
	RTHOOK(2);
	RTEE;
}

/* {EW_EWEASEL_OUTPUT_CONTROL}.append */
void F7_186 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("append", 6, Current, 0, 2, 179);
	RTGC;
	RTHOOK(1);
	tr1 = RTOSCF(24,F1_24,(Current));
	F25_402(RTCW(tr1), arg1);
	RTHOOK(2);
	if (arg2) {
		RTHOOK(3);
		F25_422(RTCV(RTOSCF(24,F1_24,(Current))));
	}
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {EW_EWEASEL_OUTPUT_CONTROL}.append_error */
void F7_187 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2)
{
	GTCX
	RTEX;
	
	
	RTEAA("append_error", 6, Current, 0, 2, 180);
	RTHOOK(1);
	F7_186(Current, arg1, arg2);
	RTHOOK(2);
	RTEE;
}

/* {EW_EWEASEL_OUTPUT_CONTROL}.append_new_line */
void F7_188 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("append_new_line", 6, Current, 0, 0, 181);
	RTGC;
	RTHOOK(1);
	F25_422(RTCV(RTOSCF(24,F1_24,(Current))));
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_EWEASEL_OUTPUT_CONTROL}.interface */
EIF_REFERENCE F7_191 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


void EIF_Minit7 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C1/ew7.c <==
/*
 * Code for class EW_EWEASEL_OUTPUT_CONTROL
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew7.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_EWEASEL_OUTPUT_CONTROL}.make */
void F7_182 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("make", 6, Current, 0, 1, 187);
	RTGC;
	RTHOOK(1);
	tr1 = RTCCL(arg1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_EWEASEL_OUTPUT_CONTROL}.flush */
void F7_184 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("flush", 6, Current, 0, 0, 189);
	RTGC;
	RTHOOK(1);
	tr1 = RTOSCF(306,F23_306,(RTCV(RTOSCF(24,F1_24,(Current)))));
	F407_2707(RTCW(tr1));
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_EWEASEL_OUTPUT_CONTROL}.update */
void F7_185 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("update", 6, Current, 0, 0, 190);
	RTHOOK(1);
	F7_184(Current);
	RTHOOK(2);
	RTEE;
}

/* {EW_EWEASEL_OUTPUT_CONTROL}.append */
void F7_186 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("append", 6, Current, 0, 2, 179);
	RTGC;
	RTHOOK(1);
	tr1 = RTOSCF(24,F1_24,(Current));
	F23_334(RTCW(tr1), arg1);
	RTHOOK(2);
	if (arg2) {
		RTHOOK(3);
		F23_354(RTCV(RTOSCF(24,F1_24,(Current))));
	}
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {EW_EWEASEL_OUTPUT_CONTROL}.append_32 */
void F7_187 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2)
{
	GTCX
	RTEX;
	struct eif_ex_22 sloc1;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) sloc1.data;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	memset (&sloc1.overhead, 0, OVERHEAD + _OBJSIZ_0_0_0_0_0_0_0_0_);
	sloc1.overhead.ov_flags = EO_EXP | EO_STACK;
	RT_DFS(&sloc1.overhead, eif_new_type(35, 0x00).id);
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,arg1);
	RTLR(4,tr2);
	RTLIU(5);
	
	RTEAA("append_32", 6, Current, 1, 2, 180);
	RTGC;
	RTHOOK(1);
	tr1 = RTOSCF(24,F1_24,(Current));
	tr2 = F36_495(RTCW(loc1), arg1);
	F23_334(RTCW(tr1), tr2);
	RTHOOK(2);
	if (arg2) {
		RTHOOK(3);
		F23_354(RTCV(RTOSCF(24,F1_24,(Current))));
	}
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {EW_EWEASEL_OUTPUT_CONTROL}.append_error */
void F7_188 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2)
{
	GTCX
	RTEX;
	
	
	RTEAA("append_error", 6, Current, 0, 2, 181);
	RTHOOK(1);
	F7_186(Current, arg1, arg2);
	RTHOOK(2);
	RTEE;
}

/* {EW_EWEASEL_OUTPUT_CONTROL}.append_new_line */
void F7_190 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("append_new_line", 6, Current, 0, 0, 183);
	RTGC;
	RTHOOK(1);
	F23_354(RTCV(RTOSCF(24,F1_24,(Current))));
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_EWEASEL_OUTPUT_CONTROL}.interface */
EIF_REFERENCE F7_193 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


void EIF_Minit7 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
